@@ -303,8 +303,7 @@ QStringList MainWindow::getDesktopFileInfo(const QString &file_name)
         if (commentMatch.hasMatch())
             comment = commentMatch.captured(1);
     }
-    // Fallback if Name is not translated
-    if (name.isEmpty()) {
+    if (name.isEmpty()) { // Fallback if Name is not translated
         re.setPattern(QStringLiteral("^Name=(.*)$"));
         QRegularExpressionMatch nameFallbackMatch = re.match(text);
         if (nameFallbackMatch.hasMatch()) {
@@ -313,8 +312,7 @@ QStringList MainWindow::getDesktopFileInfo(const QString &file_name)
                 QStringLiteral("^MX "))); // remove MX from begining of the program name (most of the MX Linux apps)
         }
     }
-    // Fallback if Comment is not translated
-    if (comment.isEmpty()) {
+    if (comment.isEmpty()) { // Fallback if Comment is not translated
         re.setPattern(QStringLiteral("^Comment=(.*)$"));
         QRegularExpressionMatch commentFallbackMatch = re.match(text);
         if (commentFallbackMatch.hasMatch())
@@ -483,15 +481,13 @@ void MainWindow::readFile(const QString &file_name)
         if (commentMatch.hasMatch())
             comment = commentMatch.captured(1);
     }
-    // Fallback if Name is not translated
-    if (name.isEmpty()) {
+    if (name.isEmpty()) { // Fallback if Name is not translated
         re.setPattern(QStringLiteral("^Name=(.*)$"));
         QRegularExpressionMatch nameFallbackMatch = re.match(text);
         if (nameFallbackMatch.hasMatch())
             name = nameFallbackMatch.captured(1);
     }
-    // Fallback if Comment is not translated
-    if (comment.isEmpty()) {
+    if (comment.isEmpty()) { // Fallback if Comment is not translated
         re.setPattern(QStringLiteral("^Comment=(.*)$"));
         QRegularExpressionMatch commentFallbackMatch = re.match(text);
         if (commentFallbackMatch.hasMatch())
@@ -502,8 +498,7 @@ void MainWindow::readFile(const QString &file_name)
 
     auto lines = text.split("\n");
     for (const QString &line : lines) {
-        if (line.startsWith(QLatin1String("name"), Qt::CaseInsensitive)
-            || line.startsWith(QLatin1String("comment"), Qt::CaseInsensitive) || line.isEmpty()
+        if (line.startsWith(QLatin1String("Name")) || line.startsWith(QLatin1String("Comment")) || line.isEmpty()
             || line.startsWith(QLatin1String("#")))
             continue;
         processLine(line);
